pub fn parse_inbound_text(text: &str) -> Option<RelayEvent>Expand description
Recognize an inbound peer envelope or notice in the text Claude handed a relay.
pub fn parse_inbound_text(text: &str) -> Option<RelayEvent>Recognize an inbound peer envelope or notice in the text Claude handed a relay.