pub enum HarnessAuthenticationMethodId {
Browser,
DeviceCode,
}Expand description
Stable identifier for a harness-native authentication mechanism.
Variants
Browser
The native CLI opens or directs the user to a browser sign-in.
DeviceCode
The native CLI prints a device code completed in another browser.