pub fn read(locator: &SessionLocator) -> ValueExpand description
The agent variables recorded for the session at locator, or null when its launch named none.
pub fn read(locator: &SessionLocator) -> ValueThe agent variables recorded for the session at locator, or null when its launch named none.