pub fn discover_live_runtime(
source: &LiveRuntimeSource,
) -> Result<Option<LiveRuntimeEndpoint>, LiveRuntimeReceiptError>Expand description
Find the newest live receipt matching a discovered source session.
pub fn discover_live_runtime(
source: &LiveRuntimeSource,
) -> Result<Option<LiveRuntimeEndpoint>, LiveRuntimeReceiptError>Find the newest live receipt matching a discovered source session.