close_idle_threads

Function close_idle_threads 

pub fn close_idle_threads(homes: &HarnessHomes)
End the process of every thread session the mailbox launched that has been idle longer than its agent’s idle_minutes (decision 9), through supercode close. Its transcript stays; the next reply in its thread resumes it.