pub fn register_folder_sessions(homes: &HarnessHomes)Expand description
Register as a thread every running session started directly in an agent’s
folder that is neither its main session nor a thread’s holder: its terminal
is a thread (s-<session id>), with main CC.