pub fn thread_held_by(address: &MailAddress) -> Option<Thread>Expand description
The thread address holds for an agent other than as its main session:
a delegated session holds exactly one (its side conversations aside).
pub fn thread_held_by(address: &MailAddress) -> Option<Thread>The thread address holds for an agent other than as its main session:
a delegated session holds exactly one (its side conversations aside).