message_id_for

Function message_id_for 

pub fn message_id_for(sender: &MailAddress, key: Option<&str>) -> Result<String>
The id of a message sender sends under key: a key that is itself a whole message id (m- and 24 lowercase hex digits) is that id, so a sender that chose it beforehand (a board blocking a card on the answer to the question it is about to send) knows what the answer will name; any other key is hashed with the sender’s address; no key is a fresh id.