deliver

Function deliver 

pub async fn deliver(
    envelope: &Envelope,
    to: &MailAddress,
    door: &Door,
    wake: bool,
    notify_when_idle: bool,
) -> Result<Result<Delivered, Refused>, String>
Deliver envelope to to through door. With wake false an idle receiver is not started. With notify_when_idle the sender gets one idle notice after the receiver’s next turn ends.