pub fn has_message_tools(pid: u32) -> boolExpand description
Whether the session process pid has supercode’s messaging tools: a
harness starts each MCP server as a child of the session, so the tools are
loaded exactly when a live supercode message mcp is one of its children.