pub struct CodexThread {
pub address: MailAddress,
pub parent: MailAddress,
pub status: String,
pub cwd: Option<PathBuf>,
}Expand description
A running Codex subagent thread and the conversation Codex recorded as its parent.
Fields
address: MailAddressIts address.
parent: MailAddressThe conversation that spawned it, as Codex recorded it.
status: StringIts rollout’s state (busy, idle, …).
cwd: Option<PathBuf>Its working directory.