pub fn answer_id(address: &MailAddress, native_id: &str) -> StringExpand description
The id of the answer the transcript entry native_id records in the
session at address: a- and 24 hex digits.
pub fn answer_id(address: &MailAddress, native_id: &str) -> StringThe id of the answer the transcript entry native_id records in the
session at address: a- and 24 hex digits.