pub fn read(
homes: &HarnessHomes,
address: &MailAddress,
) -> Option<TranscriptMail>Expand description
The transcript’s reading of the session at address, when it can be read.
pub fn read(
homes: &HarnessHomes,
address: &MailAddress,
) -> Option<TranscriptMail>The transcript’s reading of the session at address, when it can be read.