sent_by

Function sent_by 

pub fn sent_by(
    root: &Path,
    address: &MailAddress,
) -> Vec<(MailAddress, StoredEnvelope)>
Everything the session at address sent that is filed on this machine under root: its messages to other sessions and its answers to its user, each with the mailbox it is filed in, oldest first.