user_address

Function user_address 

pub fn user_address(machine: &str) -> Result<MailAddress>
The mailbox of the person who uses the sessions on machine: where the lines they type come from and where the sessions’ answers go.