pub fn machine_wait(root: &Path, machine: &str) -> Option<MachineWait>Expand description
The wait this machine’s mail keeps for machine, when it answered offline.
pub fn machine_wait(root: &Path, machine: &str) -> Option<MachineWait>The wait this machine’s mail keeps for machine, when it answered offline.