pub fn waiting_mail(root: &Path) -> Vec<WaitingMail>Expand description
Every message on this machine holding a wake that has had to wait (an attempt failed, or its machine is offline), oldest first.
pub fn waiting_mail(root: &Path) -> Vec<WaitingMail>Every message on this machine holding a wake that has had to wait (an attempt failed, or its machine is offline), oldest first.