pub async fn refresh_token(
client: &Client,
ep: &OAuthEndpoints,
refresh_token: &str,
) -> Result<McpOAuthTokens>Expand description
Exchange a refresh token for a new access token.
pub async fn refresh_token(
client: &Client,
ep: &OAuthEndpoints,
refresh_token: &str,
) -> Result<McpOAuthTokens>Exchange a refresh token for a new access token.