schema

Function schema 

pub fn schema() -> Schema
The JSON Schema of the whole orchestration value, with every record it contains as a definition — what supercode ontology schema prints and what the TypeScript types are generated from (ONT-6).