pub enum CapCount {
Runs,
Cards,
Sessions,
Turns,
Starts,
}Expand description
What a cap counts.
Variants
Runs
Cards with a live run.
Cards
Cards, each once whatever its runs and sessions (a cap’s where names the statuses that hold a slot).
Sessions
Live sessions the home’s cards hold, in every slot (implementer and reviewer), idle or working.
Turns
Those of the sessions that are in a turn now.
Starts
Cards started in this tick.