pub struct Expr(pub String);Expand description
An expression over the card, its relations, the event and params (a small CEL-like language: literals,
card.*, event.*, params.*, comparisons, &&/||/!, in, and the engine’s functions such as
parents.all(p, …)). Written as a string; a bare number, boolean or null is the literal it spells.
Tuple Fields
0: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Expr
impl<'de> Deserialize<'de> for Expr
Sourcefn deserialize<D>(d: D) -> Result<Expr, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(d: D) -> Result<Expr, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Expr
Sourceimpl JsonSchema for Expr
impl JsonSchema for Expr
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for Expr
impl Serialize for Expr
Sourcefn serialize<S>(
&self,
s: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
s: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Expr