pub struct StorageRule {
pub guard: Expr,
pub status: String,
}Expand description
Ordered lowering rule for Hermes’s fixed dispatcher.
Fields
guard: Exprstatus: StringTrait Implementations
Sourceimpl Clone for StorageRule
impl Clone for StorageRule
Sourcefn clone(&self) -> StorageRule
fn clone(&self) -> StorageRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageRule
impl Debug for StorageRule
Sourceimpl<'de> Deserialize<'de> for StorageRule
impl<'de> Deserialize<'de> for StorageRule
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StorageRule, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StorageRule, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StorageRule
Sourceimpl JsonSchema for StorageRule
impl JsonSchema for StorageRule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StorageRule
impl PartialEq for StorageRule
Sourceimpl Serialize for StorageRule
impl Serialize for StorageRule
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for StorageRule