absolute_program

Function absolute_program 

pub fn absolute_program(program: &str) -> String
launchd and systemd start a unit with a minimal PATH, so the unit names the interpreter absolutely wherever one can be resolved.