pub enum SessionPresence {
Persisted,
Running,
ShuttingDown,
}Expand description
Whether a durable session currently has a proven live owner.
Variants
Persisted
The session is durable, but no live owner is proven.
Running
A harness or Supercode runtime currently owns the session.
ShuttingDown
A Supercode-owned runtime is shutting down.