pub struct NativeSupport {
pub discover: ImplementationKind,
pub load: ImplementationKind,
pub follow: ImplementationKind,
pub import: ImplementationKind,
pub export: ImplementationKind,
}Expand description
Persisted-session and translation implementation facts.
Fields
discover: ImplementationKindWhether the catalog can discover this harness’s sessions.
load: ImplementationKindWhether the core can load this harness’s native persisted format.
follow: ImplementationKindWhether the generic follower can open this harness’s native storage.
import: ImplementationKindWhether the canonical session can import this native format.
export: ImplementationKindWhether the canonical session can export this native format.