pub fn live_rollouts(sessions_root: &Path) -> HashMap<PathBuf, CodexPeerStatus>Expand description
Every Codex rollout currently held open by a stock codex process, with
the narrowest activity state its own event stream proves.
pub fn live_rollouts(sessions_root: &Path) -> HashMap<PathBuf, CodexPeerStatus>Every Codex rollout currently held open by a stock codex process, with
the narrowest activity state its own event stream proves.