pub fn find_message( root: &Path, id: &str, ) -> Result<Option<(Mailbox, StoredEnvelope)>>
Where the message id is filed on this machine: the mailbox of the session that received it, and the envelope.
id