pub fn record(tree: &Value) -> Result<&'static str>Expand description
Append tree to the journal when its shape differs from the last recorded one, else a heartbeat when the last
record is [HEARTBEAT_MS] old. Returns what was written: "tree", "heartbeat" or "nothing".